from cpl_core.console import Console, ForegroundColorEnum
from runtime.abc.runtime_service_abc import RuntimeServiceABC
from runtime.model.error import Error


class RuntimeService(RuntimeServiceABC):

    def __init__(self):
        self._line_count = 0
        self._file = ''

    @property
    def line_count(self) -> int:
        return self._line_count

    @line_count.setter
    def line_count(self, line_count: int):
        self._line_count = line_count

    @property
    def file(self) -> str:
        return self._file
    @file.setter
    def file(self, value: str):
        self._file = value

    def input(self, prefix: str) -> str:
        return Console.read_line(prefix)

    def output(self, text: str) -> None:
        Console.write_line(f'> {text}')

    def error(self, error: Error) -> None:
        Console.set_foreground_color(ForegroundColorEnum.red)
        if self._file is not None:
            Console.write_line(f'Error in {self._file} line {self._line_count}\n{error.message}')
        else:
            Console.write_line(f'Error in line {self._line_count}\n{error.message}')
        Console.color_reset()
        Console.write_line()
        exit()

    def runtime_error(self, error: Error) -> None:
        Console.set_foreground_color(ForegroundColorEnum.red)
        Console.write_line(f'{error.message}', 'red')
        Console.color_reset()
        Console.write_line()
        exit()
